@@ -60,12 +60,18 @@ Plack::Middleware - Base class for easy-to-use PSGI middleware
 
 =head1 DESCRIPTION
 
-Plack::Middleware is an utility base class to write PSGI
+Plack::Middleware is a utility base class to write PSGI
 middleware. All you have to do is to inherit from Plack::Middleware
 and then implement the callback C<call> method (or C<to_app> method
 that would return the PSGI code reference) to do the actual work. You
 can use C<< $self->app >> to call the original (wrapped) application.
 
+Your middleware object is created at a PSGI application compile time
+and is persistent during the web server life cycle (unless it is a
+non-persisten environment such as CGI), so you should never set or
+cache per-request data like C<$env> in your middleware object. See
+also L<Plack::Component/"OBJECT LIFECYCLE">.
+
 See L<Plack::Builder> how to actually enable middlewares in your
 I<.psgi> application file using the DSL. If you do not like our
 builder DSL, you can also use C<wrap> method to wrap your application
@@ -79,6 +85,6 @@ with a middleware:
 
 =head1 SEE ALSO
 
-L<Plack> L<Plack::Builder>
+L<Plack> L<Plack::Builder> L<Plack::Component>
 
 =cut
